@@ -893,6 +893,7 @@ int http_upload_file(const char* url, const char* proxy, const int port, gchar**
     struct curl_httppost *lastptr=NULL;
     struct curl_slist *headerlist=NULL;
     static const char buf[] = "Expect:";
+    gchar* tmp = NULL;
 
     chunk.memory = NULL;
     chunk.size = 0;
@@ -905,13 +906,15 @@ int http_upload_file(const char* url, const char* proxy, const int port, gchar**
     /* Fill in the file upload field */
     if (file->params != NULL){
         while(file->params[i] != NULL){
+            tmp = g_uri_unescape_string(file->params[i+1], NULL);
             curl_formadd(&formpost,
                           &lastptr,
                  CURLFORM_COPYNAME, file->params[i],
-             CURLFORM_COPYCONTENTS, file->params[i+1],
+             CURLFORM_COPYCONTENTS, tmp,
                       CURLFORM_END);
-            msa_debug("%s = %s", file->params[i], file->params[i+1]);
+            msa_debug("%s = %s", file->params[i], tmp);
             i = i + 2;
+            g_free(tmp);
         }
     }
 
