@@ -79,14 +79,6 @@ SgLclGRtTAfPQLs0TjvgDft/f/LX85s0Pbu/sSDtdCLW5nTqDhSYM33sgUxPz1V5cc7/x/Mfr27y\
 #  define CLIENT_ID "133410120012716" 
 #endif
 
-#define OLD_AUTH_URL "https://graph.facebook.com/oauth/authorize?client_id="\
-CLIENT_ID\
-"&redirect_uri=https://www.facebook.com/connect/login_success.html&type=user_agent&display=touch&scope=user_birthday,friends_birthday,user_photos,friends_photos,user_location,friends_location,publish_stream,friends_online_presence,user_about_me,user_status,friends_status,user_about_me,friends_about_me,user_hometown,friends_hometown,read_mailbox,user_photo_video_tags,friends_photo_video_tags"
-
-#define AUTH_URL "https://www.facebook.com/dialog/oauth?response_type=token&client_id="\
-CLIENT_ID\
-"&redirect_uri=https://www.facebook.com/connect/login_success.html&type=user_agent&display=touch&scope=user_birthday,friends_birthday,user_photos,friends_photos,user_location,friends_location,publish_stream,friends_online_presence,user_about_me,user_status,friends_status,user_about_me,friends_about_me,user_hometown,friends_hometown,read_mailbox"
-
 /*user_relationships,friends_relationships,user_religion_politics,friends_religion_politics,user_religion_politics,friends_religion_politics,user_education_history,friends_education_history,*/
 #define LOGIN_SUCCESS "^http[s]{,1}://www\\.facebook\\.com/connect/login_success\\.html.*"
 
