@@ -22,6 +22,12 @@
 #ifndef _PARSER_H_
 #define _PARSER_H_
 
+/*
+ * MSA_UNUSED is used to prevent warnings about unused variables.
+ * Use with caution, because this may complicate the detection of errors.
+ */
+#define MSA_UNUSED(x) (void)x;
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stddef.h>
@@ -41,5 +47,6 @@ int empty_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data,
 int download_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response);
 int text_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response);
 int webauth_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response);
+int webcaptcha_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response);
 void process_url(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response);
 #endif
